@@ -2,7 +2,8 @@ import os
 import sys
 import curses
 import shlex
-from functools import reduce
+
+from urwid.util import calc_width
 
 curses.setupterm()
 e3_seq = curses.tigetstr('E3') or b''
@@ -55,3 +56,6 @@ def file_to_class_name(file_name):
 
 def file_readable(filepath):
     return os.path.isfile(filepath) and os.access(filepath, os.R_OK)
+
+def unicode_len(string):
+    return calc_width(string, 0, len(string))
